@@ -6,38 +6,33 @@ import cx from 'classnames';
 import React from 'react';
 import PropTypes from 'prop-types';
 import { iconCaretDown } from 'carbon-icons';
-import { Icon } from 'carbon-components-react';
-
+import { settings } from 'carbon-components';
+import Icon from '../Icon';
+var prefix = settings.prefix;
 export var translationIds = {
   'close.menu': 'close.menu',
   'open.menu': 'open.menu'
 };
-
 var defaultTranslations = (_defaultTranslations = {}, _defineProperty(_defaultTranslations, translationIds['close.menu'], 'Close menu'), _defineProperty(_defaultTranslations, translationIds['open.menu'], 'Open menu'), _defaultTranslations);
-
 /**
  * `ListBoxMenuIcon` is used to orient the icon up or down depending on the
  * state of the menu for a given `ListBox`
  */
+
 var ListBoxMenuIcon = function ListBoxMenuIcon(_ref) {
+  var _cx;
+
   var isOpen = _ref.isOpen,
       t = _ref.translateWithId;
-
-  var className = cx({
-    'bx--list-box__menu-icon': true,
-    'bx--list-box__menu-icon--open': isOpen
-  });
+  var className = cx((_cx = {}, _defineProperty(_cx, "".concat(prefix, "--list-box__menu-icon"), true), _defineProperty(_cx, "".concat(prefix, "--list-box__menu-icon--open"), isOpen), _cx));
   var description = isOpen ? t('close.menu') : t('open.menu');
-  return React.createElement(
-    'div',
-    { className: className },
-    React.createElement(Icon, {
-      icon: iconCaretDown,
-      description: description,
-      name: 'icon--caret--down',
-      alt: description
-    })
-  );
+  return React.createElement("div", {
+    className: className
+  }, React.createElement(Icon, {
+    icon: iconCaretDown,
+    description: description,
+    alt: description
+  }));
 };
 
 ListBoxMenuIcon.propTypes = {
@@ -54,11 +49,9 @@ ListBoxMenuIcon.propTypes = {
    */
   translateWithId: PropTypes.func.isRequired
 };
-
 ListBoxMenuIcon.defaultProps = {
   translateWithId: function translateWithId(id) {
     return defaultTranslations[id];
   }
 };
-
 export default ListBoxMenuIcon;
\ No newline at end of file
