@@ -528,7 +528,6 @@ module.exports = {
 	"8.5.0": "80.0.3987.165",
 	"8.5.1": "80.0.3987.165",
 	"8.5.2": "80.0.3987.165",
-	"8.5.3": "80.0.3987.163",
 	"9.0.0-beta.1": "82.0.4048.0",
 	"9.0.0-beta.2": "82.0.4048.0",
 	"9.0.0-beta.3": "82.0.4048.0",
@@ -703,8 +702,6 @@ module.exports = {
 	"11.0.0-beta.13": "87.0.4280.11",
 	"11.0.0-beta.16": "87.0.4280.27",
 	"11.0.0-beta.17": "87.0.4280.27",
-	"11.0.0-beta.18": "87.0.4280.27",
-	"11.0.0-beta.19": "87.0.4280.27",
 	"11.0.0-nightly.20200525": "84.0.4129.0",
 	"11.0.0-nightly.20200526": "84.0.4129.0",
 	"11.0.0-nightly.20200529": "85.0.4156.0",
@@ -756,7 +753,5 @@ module.exports = {
 	"12.0.0-nightly.20201014": "87.0.4268.0",
 	"12.0.0-nightly.20201015": "87.0.4268.0",
 	"12.0.0-nightly.20201023": "88.0.4292.0",
-	"12.0.0-nightly.20201026": "88.0.4292.0",
-	"12.0.0-nightly.20201030": "88.0.4306.0",
-	"12.0.0-nightly.20201102": "88.0.4306.0"
+	"12.0.0-nightly.20201026": "88.0.4292.0"
 };
\ No newline at end of file
